@@ -1,3 +1,4 @@
+import abc
 from typing import List
 
 import torch
@@ -7,12 +8,19 @@ from .evaluator_base import EvaluatorBase
 from ..utils import Head, AdaptationDataset
 
 
-class Accuracy(EvaluatorBase):
+class SeqClassificationEvaluator(EvaluatorBase, abc.ABC):
+    """
+    Base class of sequence classification evaluators. Inputs format is constraint by `compatible_heads`,
+    checked when the evaluator is passed into the evaluated objective.
+    """
+    compatible_heads: List[Head] = [Head.SEQ_CLASSIFICATION]
+
+
+class SequenceAccuracy(SeqClassificationEvaluator):
     """
     Sequence classification accuracy, where each input sample of dataset falls into a single category.
     """
 
-    compatible_heads: List[Head] = [Head.SEQ_CLASSIFICATION]
     smaller_is_better: bool = False
 
     def __call__(self, model: torch.nn.Module, tokenizer: PreTrainedTokenizer, dataset: AdaptationDataset) -> float:
@@ -24,9 +32,9 @@ class Accuracy(EvaluatorBase):
 
         for batch in dataset:
             expected.extend(batch["labels"])
-            actual.extend(model(**batch).argmax(-1))
+            actual.extend(model(**batch).logits.argmax(-1))
 
         assert len(expected) == len(actual)
 
         num_correct = sum([exp == act for exp, act in zip(expected, actual)])
-        return num_correct / len(expected)
+        return num_correct.item() / len(expected)
