@@ -97,7 +97,7 @@ class Objective(abc.ABC):
         self.texts_path = None
         self.val_texts_path = None
 
-        if type(texts_or_path) == str:
+        if isinstance(texts_or_path, str):
             self.texts_path = texts_or_path
             with open(self.texts_path) as f:
                 self.dataset_length["train"] = len(f.readlines())
@@ -116,7 +116,7 @@ class Objective(abc.ABC):
             self.evaluations_history[split]["loss"] = []
 
         if val_texts_or_path is not None:
-            if type(val_texts_or_path) == str:
+            if isinstance(val_texts_or_path, str):
                 self.val_texts_path = val_texts_or_path
                 with open(self.val_texts_path) as f:
                     self.dataset_length["eval"] = len(f.readlines())
@@ -247,7 +247,7 @@ class Objective(abc.ABC):
                     objective_i: int,
                     device: Union[str, torch.device],
                     firstn: Optional[int] = None,
-                    add_oid: bool = True) -> AdaptationDataset:
+                    add_oid: bool = True) -> TransformerAdaptationDataset:
         """
         Default logic for wrapping the inputs iterator into torch.IterableDataset, used in Trainer.train_dataloaer.
         :param split: A split of the retrieved dataset. `train` or `eval`.
@@ -256,7 +256,7 @@ class Objective(abc.ABC):
         :param firstn: If given, a number of the retrieved items from the dataset.
         :param add_oid: Whether to append objective id to the match. Required for forward pass over LangModule.
 
-        :return: AdaptationDataset wrapping a data set of this objective.
+        :return: TransformerAdaptationDataset wrapping a data set of this objective.
         """
         self.epoch += 1 if split == "train" else 0
 
@@ -389,13 +389,13 @@ class SupervisedObjective(UnsupervisedObjective, abc.ABC):
                  val_labels_or_path: Optional[Union[str, List[str]]] = None,
                  **kwargs):
 
-        if type(labels_or_path) == str:
+        if isinstance(labels_or_path, str):
             self.labels_path = labels_or_path
         else:
             self.labels = labels_or_path
 
         if val_labels_or_path is not None:
-            if type(val_labels_or_path) == str:
+            if isinstance(val_labels_or_path, str):
                 self.val_labels_path = val_labels_or_path
             else:
                 self.val_labels = val_labels_or_path
