@@ -14,8 +14,15 @@ paths = {
     }
 }
 
-test_base_models = {"translation": "Helsinki-NLP/opus-mt-en-cs",
-                    "token_classification": "bert-base-multilingual-cased"}
+test_base_models = {
+    "translation_mono": "Helsinki-NLP/opus-mt-en-cs",
+    "translation_multi": {
+            "model": "sshleifer/tiny-mbart",
+            "test_src_lang": "en_XX",
+            "test_tgt_lang": "cs_CZ"},
+    "token_classification": "bert-base-multilingual-cased",
+    "sequence_classification": "bert-base-multilingual-cased"
+}
 
 training_arguments = AdaptationArguments(output_dir="adaptation_output_dir",
                                          stopping_strategy=StoppingStrategy.FIRST_OBJECTIVE_NUM_EPOCHS,
